@@ -20,12 +20,13 @@
 
 **/
 #include "MenuItemsFactory.hh"
-
+#include "config.h"
+#include <libgnome/libgnome.h>
 
 void MenuItemsFactory::setBaseMenuItems(MenuItems_t * const menu_items) const
 {
   OneMenuItems_t * tmp = new OneMenuItems_t;
-  tmp->push_back(new MenuItem("New","","",MenuItem::e_New));
+  tmp->push_back(new MenuItem(_("New"),"","",MenuItem::e_New));
   menu_items->push_back(*tmp);
   delete tmp; tmp = 0;
   return;
