@@ -22,11 +22,14 @@
 
 #include "UnlinkMenuItemsFactory.hh"
 
+#include "config.h"
+#include <libgnome/libgnome.h>
+
 MenuItems_t * UnlinkMenuItemsFactory::getMenuItems(void) const
 {
   MenuItems_t * res = new MenuItems_t;
   OneMenuItems_t * tmp = new OneMenuItems_t;
-  tmp->push_back(new MenuItem("Remove link","","",MenuItem::e_Unlink));
+  tmp->push_back(new MenuItem(_("Remove link"),"","",MenuItem::e_Unlink));
   res->push_back(*tmp);
   delete tmp; tmp = 0;
   return res;
